#
# spec file for package python-graphene-django
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-graphene-django
Version:        3.2.2
Release:        1.2
Summary:        Graphene Django integration
License:        MIT
URL:            https://github.com/graphql-python/graphene-django
Source:         https://github.com/graphql-python/graphene-django/archive/v%{version}.tar.gz#/graphene-django-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  tree
Requires:       python-Django >= 3.2
Requires:       python-graphene >= 3.0
Requires:       python-graphql-core >= 3.1.0
Requires:       python-graphql-relay >= 3.1
Requires:       python-promise >= 2.1
Requires:       python-text-unidecode
Suggests:       python-djangorestframework >= 3.6.3
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module django-filter >= 2}
BuildRequires:  %{python_module djangorestframework >= 3.6.3}
BuildRequires:  %{python_module graphene >= 3.0}
BuildRequires:  %{python_module graphql-core >= 3.1.0}
BuildRequires:  %{python_module graphql-relay >= 3.1}
BuildRequires:  %{python_module promise >= 2.1}
BuildRequires:  %{python_module psycopg2}
BuildRequires:  %{python_module pytest-django >= 3.3.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module text-unidecode}
# /SECTION
%python_subpackages

%description
Graphene Django integration.

%prep
%setup -q -n graphene-django-%{version}
sed -i 's/from mock import MagicMock/from unittest.mock import MagicMock/' graphene_django/filter/tests/conftest.py

sed -i 's/py\.test/pytest/g' graphene_django/tests/*.py graphene_django/tests/issues/*.py graphene_django/*/tests/*.py

rm setup.cfg
sed -i '/pytest-runner/d' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand find %{buildroot}%{$python_sitelib}/graphene_django -name tests | xargs rm -r
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
PYTHONPATH=${PWD}
export DJANGO_SETTINGS_MODULE=examples.django_test_settings

# The following started failing in 4.1 with b8
skips="test_integer_field_filter_type or test_other_filter_types or test_generate_graphql_file_on_call_graphql_schema or test_schema_representation"
skips="$skips or test_django_objecttype_convert_choices_enum or test_django_objecttype_choices_custom_enum_name"
skips="$skips or test_reports_validation_errors or test_errors_when_missing_operation_name or test_handles_syntax_errors_caught_by_graphql"

%pytest -k "not ($skips)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/graphene_django
%{python_sitelib}/graphene_django-%{version}.dist-info

%changelog
* Wed Nov 13 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.2.2:
  * Make use of http.HTTPStatus for response status code checks
  * Not require explicitly set ordering in DjangoConnectionField
  * fix: same type list
  * feat!: check Django model has a default ordering when used in a
    Relay Connection
- Switch to pyproject macros.
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.0:
  * Add support for validation rules
  * Provide setting to enable/disable converting choices to enums
    globally
- update to 3.1.6:
  * Only release on pypi after tests pass
  * fix: empty list is not an empty value for list filters even
    when a custom filtering method is provided
  * adding optional_field in Serializermutation to enfore some
    fields to be optional
  * Typo fixes
  * Support displaying deprecated input fields in GraphiQL docs
  * Fix graphiql explorer styles by sending missing param to
    render_graphiql
  * Add Python 3.12 to CI
  * Remove Django 4.1 (EOL) and add Django 5.0 to CI
- update to 3.1.5:
  * fix: fk resolver permissions leak
  * Support base class relations and reverse for proxy models
  * exclude 'fans' from ReporterForm tests
  * Update mutation.py to serialize Enum objects into input
    values
  * Remove Python 3.7 (EOL since EOL since 2023-06-27) from CI
  * Prevent duplicate CI runs, also work with PRs from forks
  * Use ruff in pre-commit
  * fix: foreign key nullable and custom resolver
  * Miscellaneous CI fixes
- update to 3.1.3:
  * Update the path to GraphQL Server Specification for Relay
  * Add JSONField back to graphene_django.compat module for
    backwards compatibility
- update to 3.1.2:
  * Fix linting issues
  * Set pypi GH action version to release/v1
  * Correct schema write test
  * Fix graphiql explorer styles by including official CSS, and
    update local example app for testing
  * Add check for `serializers.HiddenField` on
    `fields_for_serializer` function
  * CI: add Django 4.2
  * remove JSONField compat
  * CI: remove Django 4.0
  * Update compat.py MissingType results after PGJSONField
    removal
- update to 3.0.1:
  * Fix custom foreignkey resolvers
  * Fix broken UT due to pytest import error
  * Clarify cookbook example READMEs
  * Fix schema print with `-.graphql`
  * Update GraphiQL to 2.4.1
  * Update django-filter URL's in filtering docs
- drop python-graphene-django-no-mock.patch (upstream)
* Thu Jan 26 2023 John Vandenberg <jayvdb@gmail.com>
- Update to v3.0.0
  * See https://github.com/graphql-python/graphene-django/releases/tag/v3.0.0
- from v3.0.0b9
  * fix: unit test for https://github.com/graphql-python/graphene/pull/1412
  * Make errors in form mutation non nullable
  * Fixes related to https://github.com/graphql-python/graphene/pull/1412
  * Delay assignment of csrftoken in Graphiql
  * Fix type hint for DjangoObjectTypeOptions.model
  * Fix code examples in queries.rst
  * Fixed graphql_relay deprecation warning
  * Make instructions runnable without tweaking
  * Update tutorial-relay.rst
  * Add support to persist GraphQL headers in GraphiQL
* Sun Sep 25 2022 John Vandenberg <jayvdb@gmail.com>
- Add 12 test skips for minor differences in expected string results
- Update to v3.0.0b8
  * Adds Python 3.10 and Django 4.1 support
  * See https://github.com/graphql-python/graphene-django/compare/v3.0.0b7...v3.0.0b8
* Thu May 12 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/graphql-python/graphene-django/issues/1321
  + python-graphene-django-no-mock.patch
* Tue Jan 11 2022 John Vandenberg <jayvdb@gmail.com>
- Loosen depencencies to allow graphene v3.0.0
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Use django-codemod to make test suite Django 4 compatible
- Disable failing test test_pytest_fixture_usage which does not
  effect django-countries, the only other package using this one.
* Thu Jan 28 2021 John Vandenberg <jayvdb@gmail.com>
- Remove build dependency on pytest-runner
- Add minimum version dependencies
- Add Suggests for DRF and django-filter
- Update to v3.0.0b7
  * See https://github.com/graphql-python/graphene-django/compare/v3.0.0b3...v3.0.0b7
* Wed Sep  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- Fix test execution
* Fri Jun 12 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v3.0.0b3
* Sun Jun  7 2020 John Vandenberg <jayvdb@gmail.com>
- Activate tests
- Update to v2.10.1
* Wed Dec  4 2019 Andreas Hasenkopf <ahasenkopf@suse.com>
- New package for v2.7.1
